==> linuxconf_1.17r5.orig.tar.gz: linuxconf-1.17r5/modules/samba/samba.m <==
extern const char **_dictionary_samba;
#ifndef DICTIONARY_REQUEST
	#define DICTIONARY_REQUEST \
	const char **_dictionary_samba;\
	TRANSLATE_SYSTEM_REQ _dictionary_req_samba("samba",_dictionary_samba,106,3);\
	void dummy_dict_samba(){}
#endif
#ifndef MSG_U
	#define MSG_U(id,m)	_dictionary_samba[id]
	#define MSG_B(id,m,n)	_dictionary_samba[id]
	#define MSG_R(id)	_dictionary_samba[id]
	#define P_MSG_U(id,m)	new_trans_notload(_dictionary_samba,id)
	#define P_MSG_B(id,m,n)	new_trans_notload(_dictionary_samba,id)
	#define P_MSG_R(id)	new_trans_notload(_dictionary_samba,id)
#endif
#define M_SAMBA	0
#define T_PRIVISAMBA	1
#define T_SERVICES	2
#define F_SHARENAME	3
#define T_SHARE	4
#define I_SHARE	5
#define H_SHARES	6
#define I_NEWSHARE	7
#define T_SHARES	8
#define I_SHARES	9
#define F_COMMENT	10
#define F_PUBLIC	11
#define F_WRITABLE	12
#define F_WRITELIST	13
#define M_DEFAULT	14
#define M_HOMES	15
#define M_PRINTERS	16
#define T_SAMBA	17
#define I_SAMBA	18
#define M_SHARES	19
#define F_PREEXEC	20
#define F_ROOTPREEXEC	21
#define F_POSTEXEC	22
#define F_ROOTPOSTEXEC	23
#define F_FORCEUSER	24
#define F_FORCEGROUP	25
#define F_BROWSEABLE	26
#define F_GUESTACCOUNT	27
#define F_ENGRYPTPASS	28
#define F_PATH	29
#define F_PASSSERVER	30
#define F_PASSLEVEL	31
#define F_PASSPROG	32
#define F_PREFMASTER	33
#define F_OSLEVEL	34
#define F_NULLPASSWORDS	35
#define F_ENABLE	36
#define F_INHERIT	37
#define F_GUESTONLY	38
#define F_ADMINUSERS	39
#define F_ALLOWHOSTS	40
#define F_DENYHOSTS	41
#define F_DONTDESCEND	42
#define F_GUESTACCOUNTSH	43
#define F_VALIDUSERS	44
#define F_IVLDUSERS	45
#define F_MAGICSCRIPT	46
#define F_MAGICOUTPUT	47
#define F_MAXCONNECT	48
#define F_USERLIST	49
#define F_READLIST	50
#define F_ONLYUSER	51
#define F_DEADTIME	52
#define F_DBGLEVEL	53
#define F_DEFSERVICE	54
#define F_DOMMASTER	55
#define F_REMANNOUNCE	56
#define F_LOADPRINTERS	57
#define F_MSGCOMMAND	58
#define F_WORKGROUP	59
#define F_SERVERDESC	60
#define F_NETBIOSNAME	61
#define F_NETBIOSALIASES	62
#define F_WINSSUPPORT	63
#define F_WINSSERVER	64
#define F_INTERFACES	65
#define F_NETLOGONCOMMENT	66
#define F_LOGONSCRIPT	67
#define F_LOGONPATH	68
#define F_LOGONDRIVE	69
#define F_LOGONHOME	70
#define M_NETLOGON	71
#define T_ACCESS	72
#define T_FEATURES	73
#define M_SAMBASTATUS	74
#define N_SAMBAUSAGE	75
#define T_USERS	76
#define T_SCRIPTS	77
#define T_BASIC	78
#define T_PASSWORDS	79
#define T_NETWORKING	80
#define I_SECURITYUSER	81
#define I_SECURITYSERVER	82
#define I_SECURITYSHARE	83
#define F_SECURITY	84
#define I_SECURITYDOMAIN	85
#define T_AUTOCREATE	86
#define F_ADDUSERSCRIPT	87
#define F_DELUSERSCRIPT	88
#define F_SYNCPASSFROMSMB	89
#define I_NEVER	90
#define I_BADUSER	91
#define I_BADPASSWORD	92
#define F_MAPGUEST	93
#define F_RESOLVEORDER	94
#define F_DOMLOGONS	95
#define I_NOTMANAGED	96
#define I_MNGPASSWD	97
#define I_MNGRECORDS	98
#define F_MNGSMBPASS	99
#define F_PRINTABLE	100
#define W_WINSCONFLICT	101
#define W_NOGUESTACCOUNT	102
#define W_SHAREDUPL	103
#define W_SHAREDUPLCONF	104
#define W_PRINTERS	105

==> linuxconf_1.26r4.orig.tar.gz: linuxconf-1.26r4/modules/samba/samba.m <==
extern const char **_dictionary_samba;
#ifndef DICTIONARY_REQUEST
	#define DICTIONARY_REQUEST \
	const char **_dictionary_samba;\
	TRANSLATE_SYSTEM_REQ _dictionary_req_samba("samba",_dictionary_samba,115,3);\
	void dummy_dict_samba(){}
#endif
#ifndef MSG_U
	#define MSG_U(id,m)	_dictionary_samba[id]
	#define MSG_B(id,m,n)	_dictionary_samba[id]
	#define MSG_R(id)	_dictionary_samba[id]
	#define P_MSG_U(id,m)	new_trans_notload(_dictionary_samba,id)
	#define P_MSG_B(id,m,n)	new_trans_notload(_dictionary_samba,id)
	#define P_MSG_R(id)	new_trans_notload(_dictionary_samba,id)
#endif
#define M_SAMBA	0
#define T_PRIVISAMBA	1
#define T_SERVICES	2
#define F_SHARENAME	3
#define T_SHARE	4
#define I_SHARE	5
#define H_SHARES	6
#define I_NEWSHARE	7
#define T_SHARES	8
#define I_SHARES	9
#define F_COMMENT	10
#define F_PUBLIC	11
#define F_WRITABLE	12
#define F_WRITELIST	13
#define M_DEFAULT	14
#define M_HOMES	15
#define M_PRINTERS	16
#define T_SAMBA	17
#define I_SAMBA	18
#define M_SHARES	19
#define F_PREEXEC	20
#define F_ROOTPREEXEC	21
#define F_POSTEXEC	22
#define F_ROOTPOSTEXEC	23
#define F_FORCEUSER	24
#define F_FORCEGROUP	25
#define F_BROWSEABLE	26
#define F_GUESTACCOUNT	27
#define F_ENGRYPTPASS	28
#define F_PATH	29
#define F_PASSSERVER	30
#define F_PASSLEVEL	31
#define F_PASSPROG	32
#define F_PREFMASTER	33
#define F_OSLEVEL	34
#define F_NULLPASSWORDS	35
#define F_ENABLE	36
#define F_INHERIT	37
#define F_GUESTONLY	38
#define F_ADMINUSERS	39
#define F_ALLOWHOSTS	40
#define F_DENYHOSTS	41
#define F_DONTDESCEND	42
#define F_GUESTACCOUNTSH	43
#define F_VALIDUSERS	44
#define F_IVLDUSERS	45
#define F_MAGICSCRIPT	46
#define F_MAGICOUTPUT	47
#define F_MAXCONNECT	48
#define F_USERLIST	49
#define F_READLIST	50
#define F_ONLYUSER	51
#define F_DEADTIME	52
#define F_DBGLEVEL	53
#define F_DEFSERVICE	54
#define F_DOMMASTER	55
#define F_REMANNOUNCE	56
#define F_LOADPRINTERS	57
#define F_MSGCOMMAND	58
#define F_WORKGROUP	59
#define F_SERVERDESC	60
#define F_NETBIOSNAME	61
#define F_NETBIOSALIASES	62
#define F_WINSSUPPORT	63
#define F_WINSSERVER	64
#define F_INTERFACES	65
#define F_NETLOGONCOMMENT	66
#define F_LOGONSCRIPT	67
#define F_LOGONPATH	68
#define F_LOGONDRIVE	69
#define F_LOGONHOME	70
#define M_NETLOGON	71
#define T_ACCESS	72
#define T_FEATURES	73
#define M_SAMBASTATUS	74
#define N_SAMBAUSAGE	75
#define T_USERS	76
#define T_SCRIPTS	77
#define T_BASIC	78
#define T_PASSWORDS	79
#define T_NETWORKING	80
#define I_SECURITYUSER	81
#define I_SECURITYSERVER	82
#define I_SECURITYSHARE	83
#define F_SECURITY	84
#define I_SECURITYDOMAIN	85
#define T_AUTOCREATE	86
#define F_ADDUSERSCRIPT	87
#define F_DELUSERSCRIPT	88
#define F_SYNCPASSFROMSMB	89
#define I_NEVER	90
#define I_BADUSER	91
#define I_BADPASSWORD	92
#define F_MAPGUEST	93
#define F_RESOLVEORDER	94
#define F_DOMLOGONS	95
#define I_NOTMANAGED	96
#define I_MNGPASSWD	97
#define I_MNGRECORDS	98
#define F_MNGSMBPASS	99
#define F_PRINTABLE	100
#define W_WINSCONFLICT	101
#define W_NOGUESTACCOUNT	102
#define W_SHAREDUPL	103
#define W_SHAREDUPLCONF	104
#define W_PRINTERS	105
#define F_BROWSESYNC	106
#define T_LOGON	107
#define T_BASE	108
#define W_NETBIOSWORKGROUP	109
#define F_EXECCLOSE	110
#define F_ROOTEXECCLOSE	111
#define F_STATUSFILE	112
#define F_CREATEMASK	113
#define F_DIRMASK	114
